package com.sun.org.apache.xml.internal.security.utils;

import com.sun.org.slf4j.internal.LoggerFactory;
import java.io.OutputStream;
import java.io.IOException;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.OpenOption;
import java.nio.file.Paths;
import java.security.SecurityPermission;
import com.sun.org.slf4j.internal.Logger;

public final class JavaUtils
{
    private static final Logger LOG;
    private static final SecurityPermission REGISTER_PERMISSION;
    
    private JavaUtils() {
    }
    
    public static byte[] getBytesFromFile(String first) throws FileNotFoundException, IOException {
        byte[] byteArray = null;
        try (final InputStream inputStream = Files.newInputStream(Paths.get(first, new String[0]), new OpenOption[0]);
             final UnsyncByteArrayOutputStream unsyncByteArrayOutputStream = new UnsyncByteArrayOutputStream()) {
            byte[] b = new byte[1024];
            int read;
            while ((read = inputStream.read(b)) > 0) {
                unsyncByteArrayOutputStream.write(b, 0, read);
            }
            byteArray = unsyncByteArrayOutputStream.toByteArray();
        }
        return byteArray;
    }
    
    public static void writeBytesToFilename(String first, byte[] b) {
        if (first != null && b != null) {
            try (final OutputStream outputStream = Files.newOutputStream(Paths.get(first, new String[0]), new OpenOption[0])) {
                outputStream.write(b);
            }
            catch (IOException e) {
                JavaUtils.LOG.debug(e.getMessage(), e);
            }
        }
        else {
            JavaUtils.LOG.debug("writeBytesToFilename got null byte[] pointed");
        }
    }
    
    public static byte[] getBytesFromStream(InputStream inputStream) throws IOException {
        try (final UnsyncByteArrayOutputStream unsyncByteArrayOutputStream = new UnsyncByteArrayOutputStream()) {
            byte[] b = new byte[4096];
            int read;
            while ((read = inputStream.read(b)) > 0) {
                unsyncByteArrayOutputStream.write(b, 0, read);
            }
            return unsyncByteArrayOutputStream.toByteArray();
        }
    }
    
    public static byte[] convertDsaASN1toXMLDSIG(byte[] array, int n) throws IOException {
        if (array[0] != 48 || array[1] != array.length - 2 || array[2] != 2) {
            throw new IOException("Invalid ASN.1 format of DSA signature");
        }
        int n2;
        for (n2 = (n2 = array[3]); n2 > 0 && array[4 + n2 - n2] == 0; --n2) {}
        int n3;
        for (n3 = (n3 = array[5 + n2]); n3 > 0 && array[6 + n2 + n3 - n3] == 0; --n3) {}
        if (n2 > n || array[4 + n2] != 2 || n3 > n) {
            throw new IOException("Invalid ASN.1 format of DSA signature");
        }
        byte[] array2 = new byte[n * 2];
        System.arraycopy(array, 4 + n2 - n2, array2, n - n2, n2);
        System.arraycopy(array, 6 + n2 + n3 - n3, array2, n * 2 - n3, n3);
        return array2;
    }
    
    public static byte[] convertDsaXMLDSIGtoASN1(byte[] array, int n) throws IOException {
        int n2 = n * 2;
        if (array.length != n2) {
            throw new IOException("Invalid XMLDSIG format of DSA signature");
        }
        for (; n > 0 && array[n - n] == 0; --n) {}
        if (array[n - n] < 0) {
            ++n;
        }
        for (; n > 0 && array[n2 - n] == 0; --n) {}
        if (array[n2 - n] < 0) {
            ++n;
        }
        byte[] array2 = new byte[6 + n + n];
        array2[0] = 48;
        array2[1] = (byte)(4 + n + n);
        array2[2] = 2;
        array2[3] = (byte)n;
        System.arraycopy(array, n - n, array2, 4 + n - n, n);
        array2[4 + n] = 2;
        array2[5 + n] = (byte)n;
        System.arraycopy(array, n2 - n, array2, 6 + n + n - n, n);
        return array2;
    }
    
    public static void checkRegisterPermission() {
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            securityManager.checkPermission(JavaUtils.REGISTER_PERMISSION);
        }
    }
    
    static {
        LOG = LoggerFactory.getLogger(JavaUtils.class);
        REGISTER_PERMISSION = new SecurityPermission("com.sun.org.apache.xml.internal.security.register");
    }
}
